// CustomerAdministrationGUI .java

/* Author Michael Claudius, Roskilde Computer Science College
 * Version 1.3. 2007.05.27, 1.4 2008.11.20
 * Copyright 2003 by Michael Claudius
 * All rights reserved ?
 */
package View;

import Controller.CustomerAdministration;
import Model.Customer;
import Model.CustomerRegister;
import java.awt.event.MouseAdapter;
import java.awt.event.MouseEvent;
import java.awt.event.MouseListener;
import java.awt.event.MouseMotionListener;
import java.util.ArrayList;
import java.util.Collections;
import java.util.Comparator;
import javax.swing.JOptionPane;

public class CustomerAdministrationGUIList extends javax.swing.JFrame {

    /** Creates new form CustomerAdministrationGUI */
    public CustomerAdministrationGUIList() {
        initComponents();
        jComboBox1.addItem("Name");
        customerAdm = new CustomerAdministration();

        cprField.addMouseListener(new MouseAdapter() {

            public void mouseClicked(MouseEvent e) {
                if (e.getClickCount() == 2) {
                    System.out.println("Mouse double clicked");
                } else {
                    System.out.println("Mouse clicked on cprField");
                }
            }
        });

        this.addMouseListener(new MouseAdapter() {

            public void mouseClicked(MouseEvent e) {
                System.out.println(" JFrame clicked");
            }
        });
    }

    public CustomerAdministrationGUIList(CustomerAdministration customerAdm) {
        initComponents();
        this.customerAdm = customerAdm;

        this.addMouseListener(new MouseAdapter() {

            public void mouseClicked(MouseEvent e) {
                System.out.println(" mmmm");
            }
        });
    }
//    @Override
//    public synchronized void addMouseListener(MouseListener l) {
//        super.addMouseListener(l);
//    }
    Customer c;
    CustomerAdministration customerAdm;
    ArrayList<Customer> cList;

    private void showNumbers() {
        int num = customerAdm.getNumbers();
        String numStr = new Integer(num).toString();
        numberTextField.setText(numStr);
    }

    private void clearFields() {
        cprField.setText("");
        nameField.setText("");
        typeField.setText("");
        staysField.setText("");
        yearField.setText("");
    }

    private void createCustomer() {

        dataArea.setText("");
        String customerNo = JOptionPane.showInputDialog("State customerNo of customer: ");
        String name = JOptionPane.showInputDialog("State name of customer: ");
        String yearStr = JOptionPane.showInputDialog("State year of registration: ");
        int year = Integer.parseInt(yearStr);

        Object[] possibleValues = {"Regular", "Member", "VIP"};
        String customerType = (String) JOptionPane.showInputDialog(null, "Choose Customer Type", "Input",
                JOptionPane.QUESTION_MESSAGE, null, possibleValues, possibleValues[0]);

        c = new Customer(customerNo, name, customerType, year);
        customerAdm.addCustomer(c);
        showNumbers();
    }

    private void enterCustomer() {

        dataArea.setText("");
        //USE TEXTFIELDS DATA to read ind data in datafielsds customerNo, name etc
        String customerNo = cprField.getText();
        String name = nameField.getText();
        String yearStr = yearField.getText();
        int year = Integer.parseInt(yearStr);
        String customerType = typeField.getText();
//        String staysStr = yearField.getText();
//        int stays = Integer.parseInt(staysStr);

        int check = JOptionPane.showConfirmDialog(null, "Start registration? ", "choose one", JOptionPane.YES_NO_OPTION);

        if (check == 0) {
            if (customerAdm.registerCustomer(customerNo, name, customerType, year)) {
                dataArea.append("Registration done");
            } else {
                dataArea.append("Registration cancelled, customerNo exists");
            }
        } else {
            dataArea.append("Registration cancelled");
        }
        showNumbers();
    }

    /**Ass. 6 Show last handled customer */
    private void showCustomer() {
        dataArea.append(c.toString());
        dataArea.append(printEmptyLines(2));
    }

    /**Ass. 6 Show all customers */
    private void showAllCustomers() {
        dataArea.setText(customerAdm.allCustomersData());
        showNumbers();
    }

    private void listAllCustomers() {
        //ArrayList<Customer>
        clearFields();
        list1.removeAll();
        cList = customerAdm.listCustomersData();
        for (Customer c : cList) {
            list1.add(c.getCustomerNo() + "  " + c.getName());
        }
    }

    private void showSelectedCustomer() {
        cprField.setText(c.getCustomerNo());
        nameField.setText(c.getName());
        typeField.setText(c.getCustomerType());
        staysField.setText("" + c.getNoOfStays());
        yearField.setText("" + c.getYear());
        //Alternatively
        String yearStr = new Integer(c.getYear()).toString();
        yearField.setText(yearStr);

    }

    private void findCustomer() {
        dataArea.setText("");
        String customerNo = JOptionPane.showInputDialog("State customerNo of customer: ");
        c = customerAdm.getCustomer(customerNo);

        if (c != null) {
            showCustomer();
            cprField.setText(c.getCustomerNo());
            nameField.setText(c.getName());
            typeField.setText(c.getCustomerType());
            staysField.setText("" + c.getNoOfStays());

            yearField.setText("" + c.getYear());
            //Alternatively
            String yearStr = new Integer(c.getYear()).toString();
            yearField.setText(yearStr);

        } else {
            dataArea.setText("No customer found");
        }
    }

    private void deleteCustomer() {

        findCustomer();
        int check = JOptionPane.showConfirmDialog(null, "Remove customer? ", "choose one", JOptionPane.YES_NO_OPTION);

        if (check == 0) {
            customerAdm.removeCustomer(c.getCustomerNo());
            dataArea.setText("Customer removed");
        } else {
            dataArea.append("Cancelled. Not removed");
        }
        showNumbers();
        clearFields();
    }

    private void deleteCustomerFromList() {

        //findCustomer();
        int check = JOptionPane.showConfirmDialog(null, "Remove customer? ", "choose one", JOptionPane.YES_NO_OPTION);
        if (check == 0) {
            int index = cList.indexOf(c);
            //automatically removes from cList as cList refers to customers in CustomerRegister
            customerAdm.removeCustomer(c.getCustomerNo());
            // DONT do cList.remove(index);
            cList.remove(c);  //if you are using a local list anyway its a safe choice wont do any harm
            list1.remove(index);  //alternatively list1.remove(c.getCustomerNo() + "  " + c.getName());
            dataArea.setText("Customer removed");
        } else {
            dataArea.append("Cancelled. Not removed");
        }
        showNumbers();
        clearFields();
    }

    private void editCustomer1() {
        //Must be used in combination with findCustomer to create the object c

        int check = JOptionPane.showConfirmDialog(null, "Save changes", "choose one", JOptionPane.YES_NO_OPTION);

        if (check == 0) {
            String customerNo = c.getCustomerNo();
            String newCustomerNo = cprField.getText();
            String name = nameField.getText();
            String yearStr = yearField.getText();
            int year = Integer.parseInt(yearStr);
            String customerType = typeField.getText();
            String staysStr = staysField.getText();
            int stays = Integer.parseInt(staysStr);

            customerAdm.editCustomer(customerNo, newCustomerNo, name, customerType, year, stays);
            listAllCustomers();
            dataArea.setText("Customer changed");
        } else {
            dataArea.append("Cancelled. Not changed");
        }
        showNumbers();
    }

    private void editCustomer() {

        int check = JOptionPane.showConfirmDialog(null, "Save changes", "choose one", JOptionPane.YES_NO_OPTION);
        if (check == 0) {
            customerAdm.removeCustomer(c.getCustomerNo());
            enterCustomer();

//            String customerNo = cprField.getText();
//            String name = nameField.getText();
//            String yearStr = yearField.getText();
//            int year = Integer.parseInt(yearStr);
//            String customerType = typeField.getText();
//            String state = stateField.getText();
//            customerAdm.registerCustomerInfo(customerNo, name, customerType, year);
//
            dataArea.setText("Customer edited");
        } else {
            dataArea.append("Cancelled. Not removed");
        }
//        showNumbers();
    }

    private void closeWindow() {
        this.dispose();
    }

    private String printEmptyLines(int noLines) {
        String s = "";
        for (int i = 0; i < noLines; i++) {
            s = s + "\n";
        }
        return s;
    }

    /** This method is called from within the constructor to
     * initialize the form.
     * WARNING: Do NOT modify this code. The content of this method is
     * always regenerated by the Form Editor.
     */
    @SuppressWarnings("unchecked")
    // <editor-fold defaultstate="collapsed" desc="Generated Code">//GEN-BEGIN:initComponents
    private void initComponents() {

        jPanel1 = new javax.swing.JPanel();
        jScrollPane1 = new javax.swing.JScrollPane();
        dataArea = new javax.swing.JTextArea();
        showButton = new javax.swing.JButton();
        showAllButton = new javax.swing.JButton();
        dataLabel = new javax.swing.JLabel();
        startButton = new javax.swing.JButton();
        cprField = new javax.swing.JTextField();
        jLabel1 = new javax.swing.JLabel();
        nameField = new javax.swing.JTextField();
        jLabel2 = new javax.swing.JLabel();
        jLabel3 = new javax.swing.JLabel();
        jLabel4 = new javax.swing.JLabel();
        yearField = new javax.swing.JTextField();
        typeField = new javax.swing.JTextField();
        jLabel5 = new javax.swing.JLabel();
        staysField = new javax.swing.JTextField();
        registerButton = new javax.swing.JButton();
        jLabel6 = new javax.swing.JLabel();
        numberTextField = new javax.swing.JTextField();
        searchButton = new javax.swing.JButton();
        editButton = new javax.swing.JButton();
        deleteButton = new javax.swing.JButton();
        list1 = new java.awt.List();
        jComboBox1 = new javax.swing.JComboBox();
        jButton1 = new javax.swing.JButton();

        setDefaultCloseOperation(javax.swing.WindowConstants.EXIT_ON_CLOSE);

        dataArea.setColumns(20);
        dataArea.setRows(5);
        dataArea.addMouseListener(new java.awt.event.MouseAdapter() {
            public void mouseClicked(java.awt.event.MouseEvent evt) {
                dataAreaMouseClicked(evt);
            }
        });
        jScrollPane1.setViewportView(dataArea);

        showButton.setText("Show Customer");
        showButton.addActionListener(new java.awt.event.ActionListener() {
            public void actionPerformed(java.awt.event.ActionEvent evt) {
                showButtonActionPerformed(evt);
            }
        });

        showAllButton.setText("Show All Customer");
        showAllButton.addActionListener(new java.awt.event.ActionListener() {
            public void actionPerformed(java.awt.event.ActionEvent evt) {
                showAllButtonActionPerformed(evt);
            }
        });

        dataLabel.setFont(new java.awt.Font("MS Sans Serif", 1, 14));
        dataLabel.setText("Customer Data");

        startButton.setText("Create Customer");
        startButton.addActionListener(new java.awt.event.ActionListener() {
            public void actionPerformed(java.awt.event.ActionEvent evt) {
                startButtonActionPerformed(evt);
            }
        });

        cprField.addActionListener(new java.awt.event.ActionListener() {
            public void actionPerformed(java.awt.event.ActionEvent evt) {
                cprFieldActionPerformed(evt);
            }
        });

        jLabel1.setText("Customer Number");

        nameField.addActionListener(new java.awt.event.ActionListener() {
            public void actionPerformed(java.awt.event.ActionEvent evt) {
                nameFieldActionPerformed(evt);
            }
        });

        jLabel2.setText("Name");

        jLabel3.setText("Year");

        jLabel4.setText("Type");

        yearField.addActionListener(new java.awt.event.ActionListener() {
            public void actionPerformed(java.awt.event.ActionEvent evt) {
                yearFieldActionPerformed(evt);
            }
        });

        typeField.addActionListener(new java.awt.event.ActionListener() {
            public void actionPerformed(java.awt.event.ActionEvent evt) {
                typeFieldActionPerformed(evt);
            }
        });

        jLabel5.setText("No. Stays");

        staysField.addActionListener(new java.awt.event.ActionListener() {
            public void actionPerformed(java.awt.event.ActionEvent evt) {
                staysFieldActionPerformed(evt);
            }
        });

        registerButton.setText("Register Customer");
        registerButton.addActionListener(new java.awt.event.ActionListener() {
            public void actionPerformed(java.awt.event.ActionEvent evt) {
                registerButtonActionPerformed(evt);
            }
        });

        jLabel6.setText("Number");

        numberTextField.addActionListener(new java.awt.event.ActionListener() {
            public void actionPerformed(java.awt.event.ActionEvent evt) {
                numberTextFieldActionPerformed(evt);
            }
        });

        searchButton.setText("Search Customer");
        searchButton.addActionListener(new java.awt.event.ActionListener() {
            public void actionPerformed(java.awt.event.ActionEvent evt) {
                searchButtonActionPerformed(evt);
            }
        });

        editButton.setText("Edit Customer     ");
        editButton.addActionListener(new java.awt.event.ActionListener() {
            public void actionPerformed(java.awt.event.ActionEvent evt) {
                editButtonActionPerformed(evt);
            }
        });

        deleteButton.setText("Delete Customer  ");
        deleteButton.addActionListener(new java.awt.event.ActionListener() {
            public void actionPerformed(java.awt.event.ActionEvent evt) {
                deleteButtonActionPerformed(evt);
            }
        });

        list1.addMouseListener(new java.awt.event.MouseAdapter() {
            public void mouseClicked(java.awt.event.MouseEvent evt) {
                list1MouseClicked(evt);
            }
        });
        list1.addItemListener(new java.awt.event.ItemListener() {
            public void itemStateChanged(java.awt.event.ItemEvent evt) {
                list1ItemStateChanged(evt);
            }
        });
        list1.addActionListener(new java.awt.event.ActionListener() {
            public void actionPerformed(java.awt.event.ActionEvent evt) {
                list1ActionPerformed(evt);
            }
        });

        jComboBox1.setModel(new javax.swing.DefaultComboBoxModel(new String[] { "CustomerNo", "Name", "CustomerType", "Year" }));
        jComboBox1.addItemListener(new java.awt.event.ItemListener() {
            public void itemStateChanged(java.awt.event.ItemEvent evt) {
                jComboBox1ItemStateChanged(evt);
            }
        });
        jComboBox1.addActionListener(new java.awt.event.ActionListener() {
            public void actionPerformed(java.awt.event.ActionEvent evt) {
                jComboBox1ActionPerformed(evt);
            }
        });
        jComboBox1.addPropertyChangeListener(new java.beans.PropertyChangeListener() {
            public void propertyChange(java.beans.PropertyChangeEvent evt) {
                jComboBox1PropertyChange(evt);
            }
        });

        org.jdesktop.layout.GroupLayout jPanel1Layout = new org.jdesktop.layout.GroupLayout(jPanel1);
        jPanel1.setLayout(jPanel1Layout);
        jPanel1Layout.setHorizontalGroup(
            jPanel1Layout.createParallelGroup(org.jdesktop.layout.GroupLayout.LEADING)
            .add(jPanel1Layout.createSequentialGroup()
                .add(35, 35, 35)
                .add(jPanel1Layout.createParallelGroup(org.jdesktop.layout.GroupLayout.LEADING)
                    .add(jPanel1Layout.createSequentialGroup()
                        .add(jPanel1Layout.createParallelGroup(org.jdesktop.layout.GroupLayout.TRAILING)
                            .add(org.jdesktop.layout.GroupLayout.LEADING, deleteButton, org.jdesktop.layout.GroupLayout.DEFAULT_SIZE, 221, Short.MAX_VALUE)
                            .add(org.jdesktop.layout.GroupLayout.LEADING, editButton, org.jdesktop.layout.GroupLayout.DEFAULT_SIZE, 221, Short.MAX_VALUE)
                            .add(org.jdesktop.layout.GroupLayout.LEADING, searchButton, org.jdesktop.layout.GroupLayout.DEFAULT_SIZE, 221, Short.MAX_VALUE)
                            .add(org.jdesktop.layout.GroupLayout.LEADING, showAllButton, org.jdesktop.layout.GroupLayout.DEFAULT_SIZE, 221, Short.MAX_VALUE)
                            .add(org.jdesktop.layout.GroupLayout.LEADING, registerButton, org.jdesktop.layout.GroupLayout.DEFAULT_SIZE, 221, Short.MAX_VALUE)
                            .add(org.jdesktop.layout.GroupLayout.LEADING, showButton, org.jdesktop.layout.GroupLayout.DEFAULT_SIZE, 221, Short.MAX_VALUE)
                            .add(org.jdesktop.layout.GroupLayout.LEADING, startButton, org.jdesktop.layout.GroupLayout.DEFAULT_SIZE, 221, Short.MAX_VALUE))
                        .add(155, 155, 155))
                    .add(jPanel1Layout.createSequentialGroup()
                        .add(jPanel1Layout.createParallelGroup(org.jdesktop.layout.GroupLayout.LEADING)
                            .add(jLabel1)
                            .add(jLabel2, org.jdesktop.layout.GroupLayout.PREFERRED_SIZE, 75, org.jdesktop.layout.GroupLayout.PREFERRED_SIZE)
                            .add(jLabel3, org.jdesktop.layout.GroupLayout.PREFERRED_SIZE, 75, org.jdesktop.layout.GroupLayout.PREFERRED_SIZE)
                            .add(jLabel4, org.jdesktop.layout.GroupLayout.PREFERRED_SIZE, 75, org.jdesktop.layout.GroupLayout.PREFERRED_SIZE)
                            .add(jLabel5, org.jdesktop.layout.GroupLayout.PREFERRED_SIZE, 75, org.jdesktop.layout.GroupLayout.PREFERRED_SIZE))
                        .add(40, 40, 40)
                        .add(jPanel1Layout.createParallelGroup(org.jdesktop.layout.GroupLayout.LEADING)
                            .add(typeField, org.jdesktop.layout.GroupLayout.PREFERRED_SIZE, 155, org.jdesktop.layout.GroupLayout.PREFERRED_SIZE)
                            .add(staysField, org.jdesktop.layout.GroupLayout.PREFERRED_SIZE, 155, org.jdesktop.layout.GroupLayout.PREFERRED_SIZE)
                            .add(yearField, org.jdesktop.layout.GroupLayout.PREFERRED_SIZE, 155, org.jdesktop.layout.GroupLayout.PREFERRED_SIZE)
                            .add(nameField, org.jdesktop.layout.GroupLayout.PREFERRED_SIZE, 155, org.jdesktop.layout.GroupLayout.PREFERRED_SIZE)
                            .add(cprField, org.jdesktop.layout.GroupLayout.PREFERRED_SIZE, 155, org.jdesktop.layout.GroupLayout.PREFERRED_SIZE))
                        .add(77, 77, 77)))
                .add(jPanel1Layout.createParallelGroup(org.jdesktop.layout.GroupLayout.LEADING)
                    .add(jComboBox1, 0, 166, Short.MAX_VALUE)
                    .add(list1, org.jdesktop.layout.GroupLayout.DEFAULT_SIZE, 166, Short.MAX_VALUE)
                    .add(dataLabel)
                    .add(jPanel1Layout.createSequentialGroup()
                        .add(jLabel6)
                        .addPreferredGap(org.jdesktop.layout.LayoutStyle.RELATED, 23, Short.MAX_VALUE)
                        .add(numberTextField, org.jdesktop.layout.GroupLayout.PREFERRED_SIZE, 87, org.jdesktop.layout.GroupLayout.PREFERRED_SIZE)
                        .add(11, 11, 11))
                    .add(jScrollPane1))
                .add(134, 134, 134))
        );
        jPanel1Layout.setVerticalGroup(
            jPanel1Layout.createParallelGroup(org.jdesktop.layout.GroupLayout.LEADING)
            .add(jPanel1Layout.createSequentialGroup()
                .addContainerGap()
                .add(jPanel1Layout.createParallelGroup(org.jdesktop.layout.GroupLayout.TRAILING)
                    .add(jPanel1Layout.createSequentialGroup()
                        .add(jPanel1Layout.createParallelGroup(org.jdesktop.layout.GroupLayout.BASELINE)
                            .add(jLabel1)
                            .add(cprField, org.jdesktop.layout.GroupLayout.PREFERRED_SIZE, org.jdesktop.layout.GroupLayout.DEFAULT_SIZE, org.jdesktop.layout.GroupLayout.PREFERRED_SIZE))
                        .addPreferredGap(org.jdesktop.layout.LayoutStyle.UNRELATED)
                        .add(jPanel1Layout.createParallelGroup(org.jdesktop.layout.GroupLayout.BASELINE)
                            .add(jLabel2)
                            .add(nameField, org.jdesktop.layout.GroupLayout.PREFERRED_SIZE, org.jdesktop.layout.GroupLayout.DEFAULT_SIZE, org.jdesktop.layout.GroupLayout.PREFERRED_SIZE))
                        .add(11, 11, 11)
                        .add(jPanel1Layout.createParallelGroup(org.jdesktop.layout.GroupLayout.BASELINE)
                            .add(jLabel3)
                            .add(yearField, org.jdesktop.layout.GroupLayout.PREFERRED_SIZE, org.jdesktop.layout.GroupLayout.DEFAULT_SIZE, org.jdesktop.layout.GroupLayout.PREFERRED_SIZE))
                        .addPreferredGap(org.jdesktop.layout.LayoutStyle.UNRELATED)
                        .add(jPanel1Layout.createParallelGroup(org.jdesktop.layout.GroupLayout.BASELINE)
                            .add(jLabel4)
                            .add(typeField, org.jdesktop.layout.GroupLayout.PREFERRED_SIZE, org.jdesktop.layout.GroupLayout.DEFAULT_SIZE, org.jdesktop.layout.GroupLayout.PREFERRED_SIZE)))
                    .add(list1, org.jdesktop.layout.GroupLayout.PREFERRED_SIZE, 148, org.jdesktop.layout.GroupLayout.PREFERRED_SIZE))
                .addPreferredGap(org.jdesktop.layout.LayoutStyle.RELATED)
                .add(jPanel1Layout.createParallelGroup(org.jdesktop.layout.GroupLayout.LEADING)
                    .add(org.jdesktop.layout.GroupLayout.TRAILING, jPanel1Layout.createSequentialGroup()
                        .add(jPanel1Layout.createParallelGroup(org.jdesktop.layout.GroupLayout.BASELINE)
                            .add(jLabel5)
                            .add(staysField, org.jdesktop.layout.GroupLayout.PREFERRED_SIZE, org.jdesktop.layout.GroupLayout.DEFAULT_SIZE, org.jdesktop.layout.GroupLayout.PREFERRED_SIZE)
                            .add(jComboBox1, org.jdesktop.layout.GroupLayout.PREFERRED_SIZE, org.jdesktop.layout.GroupLayout.DEFAULT_SIZE, org.jdesktop.layout.GroupLayout.PREFERRED_SIZE))
                        .addPreferredGap(org.jdesktop.layout.LayoutStyle.UNRELATED)
                        .add(startButton)
                        .add(11, 11, 11))
                    .add(org.jdesktop.layout.GroupLayout.TRAILING, jPanel1Layout.createSequentialGroup()
                        .add(dataLabel)
                        .addPreferredGap(org.jdesktop.layout.LayoutStyle.RELATED)))
                .add(jPanel1Layout.createParallelGroup(org.jdesktop.layout.GroupLayout.TRAILING, false)
                    .add(jPanel1Layout.createSequentialGroup()
                        .add(showButton)
                        .addPreferredGap(org.jdesktop.layout.LayoutStyle.RELATED)
                        .add(registerButton)
                        .addPreferredGap(org.jdesktop.layout.LayoutStyle.UNRELATED)
                        .add(showAllButton)
                        .add(8, 8, 8)
                        .add(searchButton)
                        .addPreferredGap(org.jdesktop.layout.LayoutStyle.UNRELATED)
                        .add(editButton))
                    .add(jScrollPane1))
                .addPreferredGap(org.jdesktop.layout.LayoutStyle.RELATED)
                .add(deleteButton)
                .addPreferredGap(org.jdesktop.layout.LayoutStyle.RELATED)
                .add(jPanel1Layout.createParallelGroup(org.jdesktop.layout.GroupLayout.BASELINE)
                    .add(jLabel6)
                    .add(numberTextField, org.jdesktop.layout.GroupLayout.PREFERRED_SIZE, org.jdesktop.layout.GroupLayout.DEFAULT_SIZE, org.jdesktop.layout.GroupLayout.PREFERRED_SIZE))
                .add(36, 36, 36))
        );

        jButton1.setText("Close");
        jButton1.addActionListener(new java.awt.event.ActionListener() {
            public void actionPerformed(java.awt.event.ActionEvent evt) {
                jButton1ActionPerformed(evt);
            }
        });

        org.jdesktop.layout.GroupLayout layout = new org.jdesktop.layout.GroupLayout(getContentPane());
        getContentPane().setLayout(layout);
        layout.setHorizontalGroup(
            layout.createParallelGroup(org.jdesktop.layout.GroupLayout.LEADING)
            .add(layout.createSequentialGroup()
                .add(711, 711, 711)
                .add(jButton1)
                .addContainerGap(org.jdesktop.layout.GroupLayout.DEFAULT_SIZE, Short.MAX_VALUE))
            .add(org.jdesktop.layout.GroupLayout.TRAILING, layout.createSequentialGroup()
                .addContainerGap(63, Short.MAX_VALUE)
                .add(jPanel1, org.jdesktop.layout.GroupLayout.PREFERRED_SIZE, org.jdesktop.layout.GroupLayout.DEFAULT_SIZE, org.jdesktop.layout.GroupLayout.PREFERRED_SIZE)
                .addContainerGap())
        );
        layout.setVerticalGroup(
            layout.createParallelGroup(org.jdesktop.layout.GroupLayout.LEADING)
            .add(layout.createSequentialGroup()
                .add(jPanel1, org.jdesktop.layout.GroupLayout.PREFERRED_SIZE, org.jdesktop.layout.GroupLayout.DEFAULT_SIZE, org.jdesktop.layout.GroupLayout.PREFERRED_SIZE)
                .addPreferredGap(org.jdesktop.layout.LayoutStyle.RELATED)
                .add(jButton1)
                .addContainerGap(27, Short.MAX_VALUE))
        );

        pack();
    }// </editor-fold>//GEN-END:initComponents

private void showButtonActionPerformed(java.awt.event.ActionEvent evt) {//GEN-FIRST:event_showButtonActionPerformed
// TODO add your handling code here:
    showCustomer();
}//GEN-LAST:event_showButtonActionPerformed

private void showAllButtonActionPerformed(java.awt.event.ActionEvent evt) {//GEN-FIRST:event_showAllButtonActionPerformed
// TODO add your handling code here:
    showAllCustomers();
    listAllCustomers();
    jComboBox1.setSelectedIndex(0);
}//GEN-LAST:event_showAllButtonActionPerformed

private void startButtonActionPerformed(java.awt.event.ActionEvent evt) {//GEN-FIRST:event_startButtonActionPerformed
// TODO add your handling code here:
    createCustomer();
}//GEN-LAST:event_startButtonActionPerformed

private void cprFieldActionPerformed(java.awt.event.ActionEvent evt) {//GEN-FIRST:event_cprFieldActionPerformed
// TODO add your handling code here:
}//GEN-LAST:event_cprFieldActionPerformed

private void nameFieldActionPerformed(java.awt.event.ActionEvent evt) {//GEN-FIRST:event_nameFieldActionPerformed
// TODO add your handling code here:
}//GEN-LAST:event_nameFieldActionPerformed

private void yearFieldActionPerformed(java.awt.event.ActionEvent evt) {//GEN-FIRST:event_yearFieldActionPerformed
// TODO add your handling code here:
}//GEN-LAST:event_yearFieldActionPerformed

private void typeFieldActionPerformed(java.awt.event.ActionEvent evt) {//GEN-FIRST:event_typeFieldActionPerformed
// TODO add your handling code here:
}//GEN-LAST:event_typeFieldActionPerformed

private void staysFieldActionPerformed(java.awt.event.ActionEvent evt) {//GEN-FIRST:event_staysFieldActionPerformed
// TODO add your handling code here:
}//GEN-LAST:event_staysFieldActionPerformed

private void registerButtonActionPerformed(java.awt.event.ActionEvent evt) {//GEN-FIRST:event_registerButtonActionPerformed
// TODO add your handling code here:
    enterCustomer();
}//GEN-LAST:event_registerButtonActionPerformed

private void numberTextFieldActionPerformed(java.awt.event.ActionEvent evt) {//GEN-FIRST:event_numberTextFieldActionPerformed
// TODO add your handling code here:
}//GEN-LAST:event_numberTextFieldActionPerformed

private void searchButtonActionPerformed(java.awt.event.ActionEvent evt) {//GEN-FIRST:event_searchButtonActionPerformed
// TODO add your handling code here:
    findCustomer();
}//GEN-LAST:event_searchButtonActionPerformed

private void editButtonActionPerformed(java.awt.event.ActionEvent evt) {//GEN-FIRST:event_editButtonActionPerformed
// TODO add your handling code here:
    editCustomer1();
}//GEN-LAST:event_editButtonActionPerformed

private void deleteButtonActionPerformed(java.awt.event.ActionEvent evt) {//GEN-FIRST:event_deleteButtonActionPerformed
// TODO add your handling code here:
    //deleteCustomer();
    deleteCustomerFromList();
}//GEN-LAST:event_deleteButtonActionPerformed

private void jButton1ActionPerformed(java.awt.event.ActionEvent evt) {//GEN-FIRST:event_jButton1ActionPerformed
    // TODO add your handling code here:
    this.dispose();
}//GEN-LAST:event_jButton1ActionPerformed

private void dataAreaMouseClicked(java.awt.event.MouseEvent evt) {//GEN-FIRST:event_dataAreaMouseClicked
    // TODO add your handling code here:
    System.out.println("Mouse clicked on Textarea");
}//GEN-LAST:event_dataAreaMouseClicked

private void list1ActionPerformed(java.awt.event.ActionEvent evt) {//GEN-FIRST:event_list1ActionPerformed
    // TODO add your handling code here:
}//GEN-LAST:event_list1ActionPerformed

private void list1MouseClicked(java.awt.event.MouseEvent evt) {//GEN-FIRST:event_list1MouseClicked
    // TODO add your handling code here:
}//GEN-LAST:event_list1MouseClicked

private void list1ItemStateChanged(java.awt.event.ItemEvent evt) {//GEN-FIRST:event_list1ItemStateChanged
    // TODO add your handling code here:
    Integer i = (Integer) evt.getItem();
    c = cList.get(i);
    showSelectedCustomer();

    //System.out.println("" + evt.getItem());
    //System.out.println(c.toString());


}//GEN-LAST:event_list1ItemStateChanged

private void jComboBox1ActionPerformed(java.awt.event.ActionEvent evt) {//GEN-FIRST:event_jComboBox1ActionPerformed
    // TODO add your handling code here:
    //System.out.println("Action command"+evt.getActionCommand());
    //System.out.println("Source command"+evt.getSource());
}//GEN-LAST:event_jComboBox1ActionPerformed

private void jComboBox1ItemStateChanged(java.awt.event.ItemEvent evt) {//GEN-FIRST:event_jComboBox1ItemStateChanged
    // TODO add your handling code here:
    // System.out.println("event " + evt.getItem() + "  " + evt.getID());
    String newSortType = (String) evt.getItem();
    cList = customerAdm.sort(newSortType, cList);
    list1.removeAll();
    for (Customer c : cList) {
        list1.add(c.getCustomerNo() + "  " + c.getName());
    }
    //System.out.println("fra register\n" + customerAdm.showCustomersData());
    clearFields();

    //System.out.println("");
    //System.out.println("ID " +evt.getID());
    // System.out.println("Selectable " + evt.getItemSelectable());
}//GEN-LAST:event_jComboBox1ItemStateChanged

private void jComboBox1PropertyChange(java.beans.PropertyChangeEvent evt) {//GEN-FIRST:event_jComboBox1PropertyChange
    // TODO add your handling code here:
    // System.out.println("roperty " + evt.getNewValue());
}//GEN-LAST:event_jComboBox1PropertyChange

    /**
     * @param args the command line arguments
     */
    public static void main(String args[]) {
        java.awt.EventQueue.invokeLater(new Runnable() {

            public void run() {
                new CustomerAdministrationGUIList().setVisible(true);
            }
        });
    }
    // Variables declaration - do not modify//GEN-BEGIN:variables
    private javax.swing.JTextField cprField;
    private javax.swing.JTextArea dataArea;
    private javax.swing.JLabel dataLabel;
    private javax.swing.JButton deleteButton;
    private javax.swing.JButton editButton;
    private javax.swing.JButton jButton1;
    private javax.swing.JComboBox jComboBox1;
    private javax.swing.JLabel jLabel1;
    private javax.swing.JLabel jLabel2;
    private javax.swing.JLabel jLabel3;
    private javax.swing.JLabel jLabel4;
    private javax.swing.JLabel jLabel5;
    private javax.swing.JLabel jLabel6;
    private javax.swing.JPanel jPanel1;
    private javax.swing.JScrollPane jScrollPane1;
    private java.awt.List list1;
    private javax.swing.JTextField nameField;
    private javax.swing.JTextField numberTextField;
    private javax.swing.JButton registerButton;
    private javax.swing.JButton searchButton;
    private javax.swing.JButton showAllButton;
    private javax.swing.JButton showButton;
    private javax.swing.JButton startButton;
    private javax.swing.JTextField staysField;
    private javax.swing.JTextField typeField;
    private javax.swing.JTextField yearField;
    // End of variables declaration//GEN-END:variables
}
